#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_SPLATTED_MAXIMUM_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_SPLATTED_MAXIMUM_HPP_INCLUDED

#include <boost/simd/swar/include/functions/scalar/splatted_maximum.hpp>

#endif
